@@ -5,11 +5,12 @@ import logging
 import requests
 import socket
 import pandas as pd
+from IPython.display import HTML
 
 logger = logging.getLogger(__name__)
 
 HOST_IP = socket.gethostbyname(socket.gethostname())
-PORT = 8000
+PORT = 9000
 
 STATUS = "status"
 RESULT = "result"
@@ -28,11 +29,11 @@ QUERY_TABLE_RECORDS = """select * from {schema_name}.{table_name} limit 100;"""
 
 SERVICE_URL = f"http://{HOST_IP}:{PORT}"
 # Athena services
-API_VALIDATE_USER = "/validate_user"
-API_GET_ATHENA_DATABASES = "/get_athena_databases"
-API_GET_ATHENA_TABLES = "/get_athena_tables"
-API_QUERY_ATHENA_TABLE = "/query_athena_table"
-API_RUN_QUERY_ON_ATHENA = "/run_query_on_athena"
+API_VALIDATE_USER = "/ccf/services/validate_user"
+API_GET_ATHENA_DATABASES = "/ccf/services/get_athena_databases"
+API_GET_ATHENA_TABLES = "/ccf/services/get_athena_tables"
+API_QUERY_ATHENA_TABLE = "/ccf/services/query_athena_table"
+API_RUN_QUERY_ON_ATHENA = "/ccf/services/run_query_on_athena"
 
 HEADERS = {
     'content-type': "application/json",
@@ -89,7 +90,7 @@ class AthenaClient:
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
                     response_as_df = pd.DataFrame.from_dict(response[RESULT])
-                    return response_as_df
+                    return HTML(response_as_df.to_html(index=False))
                 else:
                     return response[RESULT]
             else:
@@ -114,7 +115,7 @@ class AthenaClient:
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
                     response_as_df = pd.DataFrame.from_dict(response[RESULT])
-                    return response_as_df
+                    return HTML(response_as_df.to_html(index=False))
                 else:
                     return response[RESULT]
             else:
@@ -139,8 +140,9 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
-                    return response_as_df
+                    results = [pd.DataFrame.from_dict(i).to_html(index=False) for i in response[RESULT]]
+                    combined_results = ''.join(results)
+                    return HTML(combined_results)
                 else:
                     return response[RESULT]
             else:
@@ -165,8 +167,9 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
-                    return response_as_df
+                    results = [pd.DataFrame.from_dict(i).to_html(index=False) for i in response[RESULT]]
+                    combined_results = ''.join(results)
+                    return HTML(combined_results)
                 else:
                     return response[RESULT]
             else:
